%define version 3.0b1pl17
Summary: The Internet Software Consortium (ISC) DHCP server
Name: dhcp
Version: %{version}
Release: 1_nw1
Group: System Environment/Daemons
Source0: ftp://ftp.isc.org/isc/dhcp/dhcp-%{version}.tar.gz
Source1: linux.init
Patch0: dhcp-%{version}-aem.patch
Copyright: ISC
BuildRoot: %{_tmppath}/dhcp-%{version}-root

%description
Dhcp includes the DHCP server which is used for dynamically configuring
hosts on a network.  Host configuration items such as IP address, name
servers, domain name, etc. can all be retrieved from the DHCP server by
a DHCP client.  This eases the burden of network wide configuration by
putting all of the configuration into one place.

%package client
Summary: A DHCP client
Group: System Environment/Configuration

%description client
Dhcp client is a DHCP client for various UNIX operating systems. It allows
a UNIX machine to obtain it's networking parameters from a DHCP server.

%package relay
Summary: A DHCP relay
Group: System Environment/Daemons

%description relay
Dhcp relay is a relay agent for DHCP packets.  It is used on a subnet with
DHCP clients to "relay" their requests to a subnet that has a DHCP server
on it.  Because DHCP packets can be broadcast, they will not be routed off
of the local subnet.  The DHCP relay takes care of this for the client.

%prep
%setup0 -q -n dhcp-%{version}
%patch0 -p1 -b .aem

%build
#./configure --with-nsupdate
./configure
if which gcc ; then
	make CC="gcc %{optflags} -Wall -W" DEBUG=
else
	make CC="cc %{optflags}" DEBUG=
fi

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}/usr/local/sbin
mkdir -p %{buildroot}/var/state/dhcp

make DESTDIR="%{buildroot}" install

%ifos linux
	mkdir -p %{buildroot}/etc/rc.d/{init,rc0,rc1,rc2,rc3,rc4,rc5,rc6}.d
	install -m 755 %{_sourcedir}/linux.init %{buildroot}/etc/rc.d/init.d/dhcpd
%else
	%ifos solaris
	mkdir -p %{buildroot}/etc/init.d
	sed -e s'|@PREFIX@|%{_prefix}|g' < contrib/solaris.init > %{buildroot}/etc/init.d/dhcpd
	chmod 755 %{buildroot}/etc/init.d/dhcpd
	%endif
%endif

# strip binaries and libraries
strip %{buildroot}%{_prefix}/sbin/* || :
for i in `find %{buildroot}/ -type 'f' -perm '+a=x' ! -name 'lib*so*'`; do
	file $i |grep -q "not stripped" && strip $i
done

%post
%ifos linux
    /sbin/chkconfig --add dhcpd
%else
    %ifos solaris
	ln /etc/init.d/dhcpd /etc/rc2.d/S90dhcpd
	ln /etc/init.d/dhcpd /etc/rc0.d/K30dhcpd
	/etc/init.d/dhcpd start
    %else
	echo "Unknown O/S.  You will need to manually configure your\nsystem"
	echo "to start the DHCP server on system startup."
    %endif
%endif

%preun
if [ $1 = 0 ]; then
    %ifos linux
	/etc/rc.d/init.d/dhcpd stop
	/sbin/chkconfig --del dhcpd
    %else
	%ifos solaris
	    /etc/init.d/dhcpd stop
	    rm /etc/rc2.d/S90dhcpd
	    rm /etc/rc0.d/K30dhcpd
	%else
	    echo "Unknown O/S.  You will need to manually clean up the DHCP"
	    echo "server startup\n in your system startup environment."
	%endif
    %endif
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYRIGHT DOCUMENTATION ISC-LICENSE README RELNOTES doc/*

%{_prefix}/sbin/dhcpd
%{_prefix}/man/man8/dhcpd.8
%{_prefix}/man/man5/dhcpd.conf.5
%{_prefix}/man/man5/dhcpd.leases.5
%{_prefix}/man/man5/dhcp-options.5
%{_prefix}/man/man5/dhcp-eval.5
%{_prefix}/man/man5/dhcp-contrib.5
%ifos linux
	%config /etc/rc.d/init.d/dhcpd
%else
	%ifos solaris
		%config /etc/init.d/dhcpd
	%endif
%endif
%dir /var/state/dhcp

%files client
/etc/dhclient-script
/sbin/dhclient
%{_prefix}/man/man8/dhclient.8
%{_prefix}/man/man8/dhclient-script.8
%{_prefix}/man/man5/dhclient.conf.5
%{_prefix}/man/man5/dhclient.leases.5
%dir /var/state/dhcp

%files relay
%{_prefix}/sbin/dhcrelay
%{_prefix}/man/man8/dhcrelay.8
%dir /var/state/dhcp

%changelog
* Fri Aug 04 2000 Eric LaForest <elafo@netwinder.org>
- Upped to pl17

* Fri Jul 7 2000 Eric LaForest <elafo@netwinder.org>
- Upped to pl16
- Added %dir directives for var/state/dhcp, as nothing works without it.

* Tue May 24 2000 Andrew E. Mileski <andrewm@netwinder.org>
- don't start dhcpd by default under linux, as it isn't configured yet
- changed directories cat1m to man8 and cat4 to man5
- removed devel package (there is none)

* Wed May 17 2000 Andrew E. Mileski <andrewm@netwinder.org>
- changed source line to correct URL
- added linux.init source
- globally changed to use macros
- added patch for linux-2.2 configuration
- removed site.local cruft (see above)
- moved configure script to build section (traditional)
- removed configure script --with-nsupdate (not supported)
- added compiler flags to make
- disabled debugging
- appropriately indented all nested conditionals

* Fri Oct  1 1999 Brian J. Murrell <brian@interlinx.bc.ca>
- write a spec file for dhcpd
